#
# spec file for package NetworkManager-vpnc
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           NetworkManager-vpnc
Version:        1.2.8
Release:        2.1
Summary:        NetworkManager VPN Support for vpnc
License:        GPL-2.0-or-later
Group:          Productivity/Networking/System
URL:            http://www.gnome.org/projects/NetworkManager
Source0:        http://download.gnome.org/sources/NetworkManager-vpnc/1.2/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM nm-vpnc-editor-interface-name.patch glgo#GNOME/NetworkManager-vpnc/commit/f4df2db6c, bsc#1213769 sckang@suse.com -- properties: Don't set interface name as empty string by default
Patch0:         nm-vpnc-editor-interface-name.patch

BuildRequires:  intltool
BuildRequires:  libxml2-tools
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk4) >= 4.0
BuildRequires:  pkgconfig(libnm) >= 1.2.0
BuildRequires:  pkgconfig(libnma) >= 1.2.0
BuildRequires:  pkgconfig(libnma-gtk4) >= 1.8.33
BuildRequires:  pkgconfig(libsecret-1)
Requires:       %{name}-frontend
Requires:       NetworkManager >= 1.2.0
Requires:       vpnc
ExcludeArch:    s390

%description
NetworkManager-vpnc provides VPN support to NetworkManager for vpnc.

%package gnome
Summary:        NetworkManager VPN Support for vpnc
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}-%{release}
Requires:       gnome-keyring
Provides:       %{name}-frontend

%description gnome
NetworkManager-vpnc provides VPN support to NetworkManager for vpnc.

%lang_package

%prep
%autosetup -p1

%build
%configure\
	--disable-static \
	--with-gtk4=yes \
	%{nil}
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%files
%license COPYING
%{_libdir}/NetworkManager/libnm-vpn-plugin-vpnc.so
%{_libexecdir}/nm-vpnc-service
%{_libexecdir}/nm-vpnc-service-vpnc-helper
%{_vpnservicedir}/nm-vpnc-service.name
%{_datadir}/dbus-1/system.d/nm-vpnc-service.conf

%files gnome
%{_datadir}/metainfo/network-manager-vpnc.metainfo.xml
%{_libexecdir}/nm-vpnc-auth-dialog
%{_libdir}/NetworkManager/libnm-vpn-plugin-vpnc-editor.so
%{_libdir}/NetworkManager/libnm-gtk4-vpn-plugin-vpnc-editor.so

%files lang -f %{name}.lang

%changelog
* Thu Aug  3 2023 Jonathan Kang <songchuan.kang@suse.com>
- Add nm-vpnc-editor-interface-name.patch: properties: Don't set
  interface name as empty string by default
  (glgo#GNOME/NetworkManager-vpnc/commit/f4df2db6c, bsc#1213769).
* Fri Mar 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.2.8:
  + libnm-glib compatibility (NetworkManager < 1.0) is disabled by
    default. It can be enabled by passing --with-libnm-glib to
    configure script. Nobody should need it by now. Users that
    still use this are encourage to let us know before the
    libnm-glib support is removed for good.
  + The auth helper in external UI mode can now be run without a
    display server. This is useful when activating connections with
    "nmcli --ask".
  + Gtk4 version of the editor plugin is now available (for use
    with Control Center of GNOME 42 or later).
  + Updated translations.
- Add pkgconfig(gtk4) and pkgconfig(libnma-gtk4) BuildRequires and
  pass --with-gtk4=yes to configure, build the gtk4 version.
- Stop passing --without-libnm-glib to configure, no longer
  needed, nor recognized.
- Add optional libxml2-tools BuildRequires, build runs
  xml-stripblanks preprocessing if available.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Fri May  1 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Set the path for the VPN service name file correctly to
  %%_vpnservicedir (provided by macros.NetworkManager).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Fri Jul 20 2018 bjorn.lie@gmail.com
- Updatet to version 1.2.6:
  + Fix for a local authenticated privileged escalation bug
    (CVE-2018-10900). All users are advised to upgrade.
  + The CA file is now hidden from the configuration dialog if
    hybrid auth is disabled.
  + Updated translations.
* Sat Apr 14 2018 bjorn.lie@gmail.com
- Following changes in NetworkManager: pass without-libnm-glib to
  configure, no longer build deprecated libnm-glib support.
- Following the above changes: Drop no longer needed
  pkgconfig(NetworkManager), pkgconfig(libnm-glib),
  pkgconfig(libnm-glib-vpn), pkgconfig(libnm-gtk) and
  pkgconfig(libnm-util) BuildRequires. Add explicit
  pkgconfig(libnm) BuildRequires.
- Package missing COPYING file.
- Stop handling icon_theme_cache_post(un) in post(un).
- Drop unneeded and unused update-desktop-files BuildRequires.
- Drop unneeded NetworkManager-gnome Requires from gnome
  sub-package, it is no longer of use for us.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Jan 23 2017 dimstar@opensuse.org
- Enable build for s390x: the entire dependency chain is in place.
* Mon Oct  3 2016 zaitor@opensuse.org
- Update to version 1.2.4:
  + Prefer building against stable libsecret API.
  + Split libnm-vpn-plugin-vpnc.so into a GTK-free core plugin
    usable by nmcli and a UI plugin for nm-applet and gnome
    components.
  + Support NM_VPN_LOG_LEVEL environment variable to control debug
    logging from NetworkManager.
  + Support multiple concurrent VPNC connections.
  + Various cleanups.
  + Updated translations.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Replace pkgconfig(libsecret-unstable) for pkgconfig(libsecret-1)
  BuildRequires following upstreams changes.
- Drop obsolete clean section.
* Sat May 14 2016 zaitor@opensuse.org
- Update to version 1.2.2:
  + Use a proper name for the AppStream metadata.
  + Updated translations.
- Stop passing --disable-more-warnings to configure, no longer
  needed.
* Tue May 10 2016 dimstar@opensuse.org
- Update to version 1.2.0:
  + build: don't include the full path to a plugin by default.
  + Updated translations.
* Tue May 10 2016 dimstar@opensuse.org
- Update to version 1.1.93 (1.2-rc1):
  + No changes.
- Changes from version 1.1.92:
  + plugin: avoid calling GetAll on service object.
  + Updated translations.
* Tue May 10 2016 dimstar@opensuse.org
- Update to version 1.1.91:
  + Updated translations.
* Tue May 10 2016 dimstar@opensuse.org
- Update to version 1.1.90:
  + Ported to libnm, libnma and GDBus.
- Add pkgconfig(libnm) and pkgconfig(libnma) BuildRequires: new
  dependencies.
- Drop nm-vpnc-desktop.patch: no longer needed.
- Drop icon sources: as there is no .desktop file, we also do not
  need an icon for it.
* Tue May 10 2016 stefan.bruens@rwth-aachen.de
- Move Requires: gnome-keyring from core package to gnome
  frontend package (boo#997343).
* Thu Apr  7 2016 sckang@suse.com
- Update to GNOME 3.20 Fate#318572
* Sun Nov 22 2015 zaitor@opensuse.org
- Update to version 1.0.8:
  + Updated translations.
* Tue Sep  1 2015 simon@simotek.net
- Update to version 1.0.6:
  + Fix error checking for write() calls.
  + Enhanced the GUI to support agent-owned and always-ask
    passwords.
  + Updated translations.
* Wed May  6 2015 dimstar@opensuse.org
- Update to version 1.0.2:
  + Updated translations.
* Tue Jan 27 2015 dimstar@opensuse.org
- Update to version 1.0.0:
  + Added option to change tunnel interface name.
  + Supports interactive password queries from vpnc ("next token
    code", etc).
  + Updated translations.
* Fri Jul 11 2014 dimstar@opensuse.org
- Update to version 0.9.10.0:
  + Uses libsecret for password storage instead of gnome-keyring.
  + Supports interactive password queries from vpnc.
  + Updated translations.
- Replace pkgconfig(gnome-keyring-1) BuildRequires with
  pkgconfig(libsecret-unstable), following upstreams switch to
  libsecret.
- Add pkgconfig(libnm-gtk) BuildRequires: new depdendency.
* Fri Sep 13 2013 dimstar@opensuse.org
- Update to version 0.9.8.6:
  + Reverted broken pid file patch from 0.9.8.4.
- Changes from version 0.9.8.4:
  + Fixed paths in VPN service file.
  + Fixed localization in non-UTF-8 locales.
  + Use /var/run/NetworkManager to store vpnc pid file.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 0.9.8.2:
  + Use full paths for auth dialog and properties plugin.
* Fri Feb 22 2013 zaitor@opensuse.org
- Update to version 0.9.8.0:
  + Builds against the GNOME 3.8 versions of GLib and Gtk+.
  + Added a "local port" setting, for servers that require
    connections to come from a specific port.
  + nm-vpnc-service now returns translated error messages.
  + Updated translations.
* Sun Dec  9 2012 dimstar@opensuse.org
- Don't package the empty README as doc file (bnc#779418).
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 0.9.6.0:
  + Support for "Application Version" setting
* Fri Jun 29 2012 dimstar@opensuse.org
- Update to version 0.9.5.95:
  + Updated translations.
* Sat Mar 24 2012 vuntz@opensuse.org
- Update to version 0.9.4.0:
  + Pass multiple domain names for NetworkManager if given by vpnc.
  + Fix auth failure in some cases.
  + Updated translations.
* Fri Mar  2 2012 dimstar@opensuse.org
- Update to version 0.9.3.995:
  + Support for Juniper/Netscreen devices
  + Support for "external UI mode" for DE-native dialogs (ie, GNOME
    Shell and others)
  + Config dialog tooltips now refer to corresponding vpnc config
    option
  + Updated translations.
- Add explicit pkgconfig(libnm-glib-vpn) BuildRequires: it's a long
  standing requirement which currently comes implicit with
  libnm-glib, as it's part of the same package at this moment.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sat Nov 12 2011 dimstar@opensuse.org
- Update to version 0.9.2.0:
  + Updated translations.
- Pass --disable-more-warnings to configure to allow building with
  gtk+ 3.3.
- Really enable parallel build: fix typo smp_flags => smp_mflags.
* Tue Nov  1 2011 dimstar@opensuse.org
- Update to version 0.9.1.95:
  + Clean up .pcf file import code.
  + Fix empty "Advanced" window after clicking the window's close
    button.
  + Updated translations.
* Tue Aug 23 2011 dimstar@opensuse.org
- Update to version 0.9.0:
  + Use right prefix for point-to-point tunnels.
  + Look for NETMASKLEN before NETMASK for IPv4 prefix.
  + Simplify password and flags handling.
  + Add support for Hybrid authentication (bgo#495893)
  + Look for old password names in the keyring too.
  + Preserve secret flags.
  + Use a simplified password request dialog.
* Wed May  4 2011 dimstar@opensuse.org
- Update to version 0.8.999:
  + Fix secret flags on import when password is saved
  + Default to agent-owned secrets for new connections.
  + Updated translations.
* Thu Apr 21 2011 vuntz@opensuse.org
- Drop unneeded BuildRequires: gconf2-devel, libglade2-devel.
- Move to pkgconfig()-style BuildRequires:
  + Old ones: NetworkManager-devel, NetworkManager-gnome,
    libgnome-keyring-devel.
  + New ones: NetworkManager, dbus-glib-1, libnm-glib, libnm-util,
    gnome-keyring-1.
- Stop owning /etc/NetworkManager/VPN as it's owned by
  NetworkManager now.
* Tue Apr  5 2011 dimstar@opensuse.org
- Update to version 0.8.998 (0.9.0-rc1):
  + Bugs fixed: bgo#645912
  + Updated translations.
- Handle new nm-vpnc-auth-dialog.desktop file.
* Wed Mar 16 2011 dimstar@opensuse.org
- Update to version 0.8.996 (0.9.0-beta2):
  + don't require glib 2.26
  + deb#615082, lp#725041: fixes for new dnsmasq
  + crash fixes
  + ifupdown plugin fixes
  + save connection timestamps in /var not /etc
  + install time fixes for Arch Linux
  + libnm-glib crash and correctness fixes
  + fix display of SSIDs in applet tooltips
  + build fixes and cleanups
  + import existing user connections
- Summary from 0.8.995 (0.9 beta1)
  + simpler, easier, more flexible, and cooler applets.
  + Fast User Switching.
  + WiMAX support.
  + System connections by default.
  + More flexible system administration.
  + Scales down to smaller devices.
- Add pkgconfig(gtk+-3.0) BuildRequires.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Remove ldconfig from %%post/%%postun: there is no library there.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
* Sat Nov  6 2010 dimstar@opensuse.org
- Update to version 0.8.2:
  + Better debugging options
  + Use random IKE source port by default
  + Updated translations.
- Split out -lang package.
* Mon Jul 26 2010 dimstar@opensuse.org
- Update to version 0.8.1:
  + Add the "Force NAT-T" option.
  + Updated translations.
* Tue Feb 23 2010 dimstar@opensuse.org
- Update to version 0.8:
  + build: disabled .desktop file for now
  + bgo#608348 - build: add missing test .pcf files to tarball
  + Updated translations.
* Thu Feb 11 2010 vuntz@opensuse.org
- Change again gnome-keyring-devel BuildRequires to
  libgnome-keyring-devel, following the module split upstream.
- Drop libgnomeui-devel, libgudev-1_0-devel, perl-XML-Parser,
  pulseaudio-esound-compat BuildRequires.
* Sat Jan 30 2010 captain.magnus@opensuse.org
- Update to version 0.7.999:
  + import/export: handle NAT Traversal modes better
  + ui: default to NAT-T instead of Cisco-UDP
  + core: fix misleading error message (deb#529747)
  + Translation updates
* Thu Jan 21 2010 tambet@novell.com
- Upgrade to the latest upstream 0.8 branch:
  + Default to NAT-T instead of Cisco-UDP.
  + Import/export improvements.
  + Respect MTU from vpnc.
  + Bug fixes.
  + Translation updates.
* Wed Dec 23 2009 vuntz@opensuse.org
- Change gnome-keyring-devel BuildRequires to
  libgnome-keyring-devel, following the module split upstream.
* Thu Dec 10 2009 vuntz@opensuse.org
- Remove perl-XML-Parser BuildRequires.
* Thu Dec 10 2009 aj@suse.de
- Remove libgnomeui-devel BuildRequires.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Fri Jun  5 2009 tambet@novell.com
- Upgrade to 0.7.1.
* Wed Feb 11 2009 vuntz@novell.com
- Remove non-upstream translations: they'll get out-of-date.
* Mon Jan 12 2009 mauro@suse.de 
- Translations update.
* Sat Dec  6 2008 mauro@suse.de
- Translations update.
* Mon Nov  3 2008 tambet@suse.de
- Use the accessors provided by NM instead of poking the private
  structures directly for settings. (a.k.a make it built with the
  latest NetworkManager again.)
* Tue Oct 28 2008 bili@suse.de
- Fixing couldn't find auth-dialog cause wrong path(#429667).
* Sat Oct 25 2008 bili@suse.de
- Bring up to date with SVN.
* Fri Sep 12 2008 tambet@suse.de
- Bring up to date with SVN.
- Require more specifc version of NetworkManager.
- Update patches so that they apply again.
* Fri Aug  8 2008 bili@suse.de
- Upgrade to 0.7.0.r3783 for fixing building error.
* Sat Aug  2 2008 tambet@suse.de
- Bring up to date with SVN again.
* Fri May 16 2008 bili@suse.de
- Upgrade to 0.7.0.r3647(bnc#372141).
* Thu Jan 17 2008 tambet@suse.de
- Upgrade to 0.7.0.
* Wed Aug  8 2007 tambet@suse.de
- Package the .so file again (Novell #298430).
* Tue Jun  5 2007 sbrabec@suse.cz
- Removed bogus definition of datadir.
- Fixed invalid desktop file patch.
- Fixed mixing of MIME and application icons.
- Call ldconfig.
- Fixed libexecdir.
* Tue Jun  5 2007 sbrabec@suse.cz
- Removed bogus definition of datadir.
- Fixed invalid desktop file patch.
- Fixed mixing of MIME and application icons.
- Call ldconfig.
* Tue May 15 2007 pgajdos@suse.cz
- removed gnome-icon-theme from BuildRequires [#247450]
* Mon Mar 19 2007 hschaa@suse.de
- Replace all occurrences of "/opt/gnome" with "%%{prefix}"
* Mon Feb 12 2007 hschaa@suse.de
- Branch off the NetworkManager-vpnc-gnome package to avoid
  gnome dependencies when using knetworkmanager instead of
  nm-applet (Novell #198529).
* Thu Nov  2 2006 tambet@suse.de
- Fetch updates from CVS:
  - Add rekeying improvements.
  - Build fixes.
  - Unable to import pcf profile (Cisco VPN) (Novell #213699).
  - Crash when trying to login to Cisco VPN (Novell #214950).
* Tue Sep  5 2006 aj@suse.de
- Cleanup BuildRequires.
* Wed Aug  2 2006 danw@suse.de
- intltoolize before autoreconf'ing to avoid version skew between
  configure macros and po/Makefile.in.in
* Fri Jun 16 2006 rml@suse.de
- Update translations (Novell bug #169096)
* Thu Jun 15 2006 gekker@suse.de
- Update package to install all existing translations (#179731)
* Mon Jun  5 2006 rml@suse.de
- Update translations (Novell bug #169096)
- Break translations out of nm-vpnc-0.6-branch.patch, place in
  separate nm-vpnc-po-update.patch
- Properties dialog: Glade file update (GNOME bug #336913)
* Thu May 18 2006 rml@suse.de
- Update translations (Novell bug #158997)
* Mon Apr 10 2006 rml@suse.de
- Report error if configuration export fails (Novell bug #164980)
* Wed Mar 29 2006 rml@suse.de
- Send MSS parameter to NetworkManager (see bug #157988)
* Mon Mar 20 2006 rml@suse.de
- Require NetworkManager-gnome (Novell bug #158691)
* Thu Feb  2 2006 rml@suse.de
- Update to 0.5.0cvs20060202
- Several cosmetic fixes
- Update API
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 rml@suse.de
- Update to 20060119
* Thu Jan 12 2006 rml@suse.de
- Update to 20060112
* Wed Jan  4 2006 rml@suse.de
- Update to 20060104
* Mon Dec 12 2005 rml@suse.de
- Update to 0.5.0cvs20051212
- Add Tango icon
* Wed Dec  7 2005 rml@suse.de
- Update to 0.5.0cvs20051207
* Thu Dec  1 2005 rml@suse.de
- Update to 0.5.0cvs20051201.
* Mon Nov 14 2005 rml@suse.de
- Update to CVS snapshot 20051114
* Fri Nov  4 2005 rml@suse.de
- Update to CVS snapshot 20051104 (fixes bug #121884)
* Wed Nov  2 2005 rml@suse.de
- Update to CVS snapshot 20051102
* Wed Oct 19 2005 rml@suse.de
- Version 0.5.0
- Update to CVS snapshot 20051019
* Thu Oct  6 2005 rml@suse.de
- Update to CVS snapshot 20051004.
* Tue Sep  6 2005 rml@suse.de
- Fix crasher bug #114803
* Tue Jul 26 2005 gekker@suse.de
- Initial import into autobuild version 0.2cvs20050722
